You are viewing a plain text version of this content. The canonical link for it is here.
Posted to cvs@httpd.apache.org by jo...@apache.org on 2021/12/13 16:24:03 UTC

svn commit: r1895905 - in /httpd/httpd/trunk: .travis.yml test/travis_before_linux.sh

Author: jorton
Date: Mon Dec 13 16:24:03 2021
New Revision: 1895905

URL: http://svn.apache.org/viewvc?rev=1895905&view=rev
Log:
Add Travis job for 2.4.x against OpenSSL 3, using APR 1.7/apr-util 1.6.
Disable TEST_MALLOC (enabled by accident) for OpenSSL 3 / trunk job.
Restrict OpenSSL 3 / apr trunk build to non-2.4.x.

Modified:
    httpd/httpd/trunk/.travis.yml
    httpd/httpd/trunk/test/travis_before_linux.sh

Modified: httpd/httpd/trunk/.travis.yml
URL: http://svn.apache.org/viewvc/httpd/httpd/trunk/.travis.yml?rev=1895905&r1=1895904&r2=1895905&view=diff
==============================================================================
--- httpd/httpd/trunk/.travis.yml (original)
+++ httpd/httpd/trunk/.travis.yml Mon Dec 13 16:24:03 2021
@@ -265,10 +265,18 @@ jobs:
            TEST_MALLOC=1 TEST_SSL=1
            CLEAR_CACHE=1
     # -------------------------------------------------------------------------
-    - name: Linux Ubuntu, Minimal module set, OpenSSL 3.x
+    - name: Linux Ubuntu, APR trunk, minimal module set, OpenSSL 3.x
+      if: *condition_not_24x
       env: APR_VERSION=trunk APR_CONFIG="--without-pgsql --without-mysql --without-odbc --with-crypto"
            CONFIG="--enable-mods-shared=ssl --with-mpm=event"
-           TEST_MALLOC=1 TEST_SSL=1 TEST_OPENSSL3=3.0.0
+           TEST_SSL=1 TEST_OPENSSL3=3.0.0
+    # -------------------------------------------------------------------------
+    - if: *condition_24x_only
+      name: Linux Ubuntu, APR 1.7, minimal module set, OpenSSL 3.x
+      env: APR_VERSION=1.7.0
+           APU_VERSION=1.6.1 APU_CONFIG="--without-pgsql --without-mysql --without-odbc --with-crypto"
+           CONFIG="--enable-mods-shared=ssl --with-mpm=event"
+           TEST_SSL=1 TEST_OPENSSL3=3.0.0
     # -------------------------------------------------------------------------
     - if: *condition_not_24x
       name: Linux Ubuntu, MPMs [event, worker], core + HTTP/2 test suite

Modified: httpd/httpd/trunk/test/travis_before_linux.sh
URL: http://svn.apache.org/viewvc/httpd/httpd/trunk/test/travis_before_linux.sh?rev=1895905&r1=1895904&r2=1895905&view=diff
==============================================================================
--- httpd/httpd/trunk/test/travis_before_linux.sh (original)
+++ httpd/httpd/trunk/test/travis_before_linux.sh Mon Dec 13 16:24:03 2021
@@ -128,12 +128,16 @@ if test -v TEST_OPENSSL3; then
            touch $HOME/root/openssl-is-${TEST_OPENSSL3}
        popd
     fi
-    # Point APR at the installed version of OpenSSL.
-    if ! test -v APR_VERSION; then
-        : APR version must be specified to build with OpenSSL 3 to avoid mismatch with system libssl/crypto
-       exit 1
+
+    # Point APR/APR-util at the installed version of OpenSSL.
+    if test -v APU_VERSION; then
+        APU_CONFIG="${APU_CONFIG} --with-openssl=$HOME/root/openssl3"
+    elif test -v APR_VERSION; then
+        APR_CONFIG="${APR_CONFIG} --with-openssl=$HOME/root/openssl3"
+    else
+        : Non-system APR/APR-util must be used to build with OpenSSL 3 to avoid mismatch with system libraries
+        exit 1
     fi
-    APR_CONFIG="${APR_CONFIG} --with-openssl=$HOME/root/openssl3"
 fi
 
 if test -v APR_VERSION; then
@@ -144,4 +148,5 @@ fi
 
 if test -v APU_VERSION; then
     install_apx apr-util ${APU_VERSION} "${APU_CONFIG}" --with-apr=$HOME/build/apr-${APR_VERSION}
+    ldd $HOME/root/apr-util-${APU_VERSION}/lib/libaprutil-?.so || true
 fi